//+------------------------------------------------------------------+
//|                                              PopupWindow.mqh |
//|                                      Copyright 2020, Dale Woods. |
//|                                      https://www.theforexguy.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2020, Dale Woods."
#property link      "https://www.theforexguy.com"
#property version   "1.00"

#include <controls/Dialog.mqh>
#include <controls/Button.mqh>
#include <controls/Label.mqh>
#include <controls/ComboBox.mqh>

class PopupWindow : public CDialog {
   private:
      string _focusedPortfolio;
      ulong _ticketSelected;
      
      CButton _okBtn;
      CButton _cancelbtn;
      CComboBox _ticketSelect;
      CLabel _title;
      
      bool CreateTitle();
      bool CreateBtns();
      bool CreateComboBox();
      
      void PopulateComboBox();
      
      void OnTicketSelect();
      
      void OnOkBtnClick();
      void OnCancelClick();
   public:
      PopupWindow();
      ~PopupWindow();
      
      bool Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2) override;
   
      bool OnEvent(const int id,const long &lparam,const double &dparam,const string &sparam) override;
      
      bool Show() override;

};

//+------------------------------------------------------------------+

PopupWindow::PopupWindow() : CDialog() {
   _focusedPortfolio = "POP UP DIALOG";
   _ticketSelected = 0;
}


PopupWindow::~PopupWindow() {

}

//+------------------------------------------------------------------+


EVENT_MAP_BEGIN(PopupWindow)
   ON_EVENT(ON_CHANGE, _ticketSelect,OnTicketSelect)
   ON_EVENT(ON_CLICK, _cancelbtn, OnCancelClick)
   ON_EVENT(ON_CLICK, _okBtn, OnOkBtnClick)
EVENT_MAP_END(CDialog)

//+------------------------------------------------------------------+
bool PopupWindow::Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2) override {
   
   if( !CDialog::Create(chart,name,subwin,x1,y1,x2,y2) ) {
      return false;
   }
   
   Visible(false);
   
   if( !CreateTitle() ) {
      return false;
   }
   
   if( !CreateComboBox() ) {
      return false;
   }
   
   if( !CreateBtns() ) {
      return false;
   }
   
   return true;
}


bool PopupWindow::CreateTitle() {
   
   string title = "ADD TICKET TO " + _focusedPortfolio;
   int fontsize = 15;
   
   int center = Width()/2;
   int headingW = Width() - 20;
  
   int _x = center - (headingW / 2);
   int _y = 10;
   
   _title.Create(0, "Add_Ticket_Dialog_Heading", 0,
      _x,
      _y,
      _x+headingW,
      _y+20
   ); 
   
   _title.Text("ADD TICKET TO " + _focusedPortfolio);
   _title.Font("Arial");
   _title.FontSize( 15);
   _title.Color(clrBlack);
   _title.Show();
   
   Add(_title);
   

   return true;
}


bool PopupWindow::CreateBtns() {
   int btnWidth = 120;
   int btnHieght = 30;
   int btnsTotalWidth = (btnWidth * 2) + 10;
   int center = (Width()/2);
   
   int x = center - (btnsTotalWidth / 2);
   int y = (_ticketSelect.Bottom() - Top()) + 10;
   
   _okBtn.Create(0, "TicketAddBtn", 0,
      x,y,
      x + btnWidth,
      y + btnHieght
   );
   
   _okBtn.Text("Add Ticket");   
   
   Add(_okBtn);   
   
   x += 10 + btnWidth;
      
   _cancelbtn.Create(0, "TicketCancelBtn", 0,
      x,y,
      x + btnWidth,
      y + btnHieght
   );
      
   _cancelbtn.Text("Cancel");
   
   Add(_cancelbtn);
   
   return true;
}

bool PopupWindow::CreateComboBox() {
   int x = 10;
   int y = (_title.Bottom() - Top()) + 10;
   
   bool result = _ticketSelect.Create(0, "ticket_combo_select", 0,
      x, y,
      Width() - 20,
      y+30
   );
   
   Add(_ticketSelect);
   
   PopulateComboBox();

   return result;
}


void PopupWindow::PopulateComboBox() {
   _ticketSelect.ItemsClear();
   
   for(int i = 0; i<10; i++) {
      string lbl = StringFormat("Item %d", i);            
      _ticketSelect.AddItem(lbl, GetMicrosecondCount());   
   }

   _ticketSelect.Select(0); 
   _ticketSelected = _ticketSelect.Value();
   
   // Disable add ticket button
   if( _ticketSelected == 0 ) {
      _okBtn.Disable();
   }
   
   else {
      _okBtn.Enable();
   }   
}


bool PopupWindow::Show() {
   PopulateComboBox();
   return CDialog::Show();
}


void PopupWindow::OnTicketSelect() {
   _ticketSelected = _ticketSelect.Value();
}


void PopupWindow::OnOkBtnClick() {
   Alert("Ok Clicked");
}

void PopupWindow::OnCancelClick() {
   Alert("Cancel Clicked");
}